//MIDI out routines

/*
   Device A CC selections
   0 - Notes
   1 - Pitch Bend (2 byte)
   2 - Modulation
   3 - Volume (2 byte)
   4 - Pan
   5 - Continuous Control 12 (2 byte)
   6 - Continuous Control 14
   7 - Continuous Control 15

   Device B CC selections
   0 - GATE: Sends Note Off messages for Device A notes
   1 - Pitch Bend (2 byte)
   2 - Volume (2 byte)
   3 - Pan
   4 - Continuous Control 13 (2 byte)
   5 - Continuous Control 16
   6 - Continuous Control 17
   7 - Continuous Control 18
*/


// Send MIDI data out
// on device A and B based on settings of switches

void A_channel_send()
{
  switch (contControl_A)
  {
    default: //Notes
      send_A = 0x80 | old_channel_A; // noe off
      Serial1.write(send_A); // note_off and MIDI channel
      Serial1.write(old_A_data); // note number
      Serial1.write(0);    // velocity
      send_A = 0x90 | channel_A; // send new note
      Serial1.write(send_A); // note_on and MIDI channel
      Serial1.write(A_data); // note number
      Serial1.write(127);    // velocity
      gateStatus = 1;
      break;

    case 1: // pitch bend
      send_A = 0xE0 | channel_A;
      Serial1.write(send_A); // pitch bend and MIDI channel
      Serial1.write(A_lowData); // high byte
      Serial1.write(A_highData); // low byte
      break;

    case 2: // modulation wheel
      send_A = 0xB0 | channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(1); // modulation
      Serial1.write(A_data); // data
      break;

    case 3: // volume
      send_A = 0xB0 | channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(7); // volume coarse
      Serial1.write(A_highData); // high byte
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(39); // volume fine
      Serial1.write(A_lowData); // low byte
      break;

    case 4: // pan
      send_A = 0xB0 | channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(10); // pan
      Serial1.write(A_data); // data
      break;

    case 5: // controller 12: 14 bit
      send_A = 0xB0 | channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(12);
      Serial1.write(A_highData);
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(44);
      Serial1.write(A_lowData);
      break;

    case 6: // controller 14
      send_A = 0xB0 | channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(14);
      Serial1.write(A_data); // data
      break;

    case 7: // controller 15
      send_A = 0xB0 | channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(15);
      Serial1.write(A_data); // data
      break;
  }
}

void B_channel_send()
{
  switch (contControl_B)
  {
    default: //  0: note off or on
      {
        if (contControl_A == 0 & newVoltage == 0) // only do this if device A is outputting notes
        {
          send_A = 0x80 | channel_A; // note OFF
          Serial1.write(send_A); // note_on and MIDI channel
          Serial1.write(A_data); // note number
          Serial1.write(0);    // velocity
          gateStatus = 0;
        }

        if (contControl_A == 0 & newVoltage == 1) // only do this if device A is outputting notes
        {
          if (gateStatus == 0) // new note needs to be sent before doing gate change
          {
            send_A = 0x90 | channel_A; // note ON
            Serial1.write(send_A); // note_on and MIDI channel
            Serial1.write(A_data); // note number
            Serial1.write(127);    // velocity
            gateStatus = 1;
          }
        }
      }
      break;

    case 1: // pitch bend
      send_B = 0xE0 | channel_B;
      Serial1.write(send_B); // pitch bend and MIDI channel
      Serial1.write(B_lowData); // high byte
      Serial1.write(B_highData); // low byte
      break;

    case 2: // volume
      send_B = 0xB0 | channel_B;
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(7); // volume
      Serial1.write(B_highData); // high byte
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(39); // volume
      Serial1.write(B_lowData); // low byte
      break;

    case 3: // pan
      send_B = 0xB0 | channel_B;
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(10); // pan
      Serial1.write(B_data); // data
      break;

    case 4: // controller 13
      send_B = 0xB0 | channel_B;
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(13);
      Serial1.write(B_highData);
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(45);
      Serial1.write(B_lowData);
      break;

    case 5: // controller 16
      send_B = 0xB0 | channel_B;
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(16);
      Serial1.write(B_data); // data
      break;

    case 6: // controller 17
      send_B = 0xB0 | channel_B;
      Serial1.write(send_B);
      Serial1.write(17);
      Serial1.write(B_data);
      break;

    case 7: // controller 18
      send_B = 0xB0 | channel_B;
      Serial1.write(send_B);
      Serial1.write(18);
      Serial1.write(B_data);
      break;
  }
}

//-----------------------------

// these routines zero out controllers if MIDI channel or CC switches are changed
// need to zero data out before changes in channel or CC
// so CCs and notes don't hang

void A_device_zero()
{
  switch (old_cc_A)
  {
    default: //Notes
      send_A = 0x80 | old_channel_A; // noe off
      Serial1.write(send_A); // note_on and MIDI channel
      Serial1.write(A_data); // note number
      Serial1.write(0);    // velocity
      break;

    case 1: // pitch bend
      send_A = 0xE0 | old_channel_A;
      Serial1.write(send_A); // pitch bend and MIDI channel
      Serial1.write(0);
      Serial1.write(64);
      break;

    case 2: // modulation wheel
      send_A = 0xB0 | old_channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(1); // modulation
      Serial1.write(0); // data
      break;

    case 3: // volume
      send_A = 0xB0 | old_channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(7); // volume
      Serial1.write(127); // high byte
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(39); // volume
      Serial1.write(127); // low byte
      break;

    case 4: // pan
      send_A = 0xB0 | old_channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(10); // pan
      Serial1.write(64); // data
      break;

    case 5: //CC12
      send_A = 0xB0 | old_channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(12);
      Serial1.write(0);
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(44);
      Serial1.write(0);
      break;

    case 6: //CC14
      send_A = 0xB0 | old_channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(14); // controller 14
      Serial1.write(0); // data
      break;

    case 7: //CC15
      send_A = 0xB0 | old_channel_A;
      Serial1.write(send_A); // controller and MIDI channel
      Serial1.write(15); // controller 13
      Serial1.write(0); // data
      break;
  }
}

void B_device_zero()
{

  switch (old_cc_B)
  {
    default:
      //send_A = 0x80 | old_channel_A; // send new note
      //Serial1.write(send_A); // note_on and MIDI channel
      //Serial1.write(A_data); // note number
      //Serial1.write(0);    // velocity
      break;

    case 1: // pitch bend
      send_B = 0xE0 | old_channel_B;
      Serial1.write(send_B); // pitch bend and MIDI channel
      Serial1.write(0);
      Serial1.write(64);
      break;

    case 2: // volume
      send_B = 0xB0 | old_channel_B;
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(7); // volume
      Serial1.write(127); // high byte
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(39); // volume
      Serial1.write(127); // low byte
      break;

    case 3: // pan
      send_B = 0xB0 | old_channel_B;
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(10); // pan
      Serial1.write(64); // data
      break;

    case 4: //
      send_B = 0xB0 | old_channel_B;
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(13);
      Serial1.write(0);
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(45);
      Serial1.write(0);
      break;

    case 5:
      send_B = 0xB0 | old_channel_B;
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(16); // controller 16
      Serial1.write(0); // data
      break;

    case 6:
      send_B = 0xB0 | old_channel_B;
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(17);
      Serial1.write(0);
      break;

    case 7:
      send_B = 0xB0 | old_channel_B;
      Serial1.write(send_B); // controller and MIDI channel
      Serial1.write(send_B);
      Serial1.write(18);
      Serial1.write(0);
      break;
  }

}

//-----------END----------------
